You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2015/04/21 18:32:40 UTC

[2/3] activemq-6 git commit: ACTIVEMQ6-97 - Change HQ to AMQ for properties/headers/doc. Remove as much HQ as possible and change to AMQ to make this close to the ActiveMQ project.

ACTIVEMQ6-97 - Change HQ to AMQ for properties/headers/doc. Remove as much HQ as possible and change to AMQ to make this close to the ActiveMQ project.


Project: http://git-wip-us.apache.org/repos/asf/activemq-6/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-6/commit/188e3b76
Tree: http://git-wip-us.apache.org/repos/asf/activemq-6/tree/188e3b76
Diff: http://git-wip-us.apache.org/repos/asf/activemq-6/diff/188e3b76

Branch: refs/heads/master
Commit: 188e3b76bd25b5fed98a52fffa8246405dce7f55
Parents: db5fd9d
Author: Jeff Genender <jg...@savoirtech.com>
Authored: Tue Apr 14 10:07:26 2015 -0600
Committer: Clebert Suconic <cl...@apache.org>
Committed: Tue Apr 21 12:26:44 2015 -0400

----------------------------------------------------------------------
 .../apache/activemq/utils/TypedProperties.java  |  6 +-
 .../activemq/api/core/FilterConstants.java      | 14 ++---
 .../org/apache/activemq/api/core/Message.java   | 20 +++----
 .../api/core/management/ManagementHelper.java   | 40 +++++++-------
 .../activemq/core/message/impl/MessageImpl.java |  8 +--
 .../org/apache/activemq/reader/MessageUtil.java |  2 +-
 .../activemq/api/jms/ActiveMQJMSConstants.java  |  8 +--
 .../activemq/jms/client/ActiveMQSession.java    |  2 +-
 .../activemq/jms/client/SelectorTranslator.java | 10 ++--
 .../activemq/jms/bridge/impl/JMSBridgeImpl.java |  4 +-
 .../openwire/OpenWireMessageConverter.java      |  2 +-
 .../core/protocol/stomp/StompConnection.java    |  4 +-
 .../rest/topic/TopicDestinationsResource.java   |  2 +-
 .../activemq/core/filter/impl/FilterImpl.java   | 12 ++--
 .../core/postoffice/impl/PostOfficeImpl.java    |  4 +-
 .../activemq/core/server/ServerMessage.java     |  2 +-
 .../core/server/impl/ActiveMQServerImpl.java    |  2 +-
 .../core/server/impl/ScaleDownHandler.java      |  4 +-
 .../activemq/core/filter/impl/FilterTest.java   | 24 ++++----
 .../apache/activemq/tools/TransferQueue.java    |  6 +-
 .../apache/activemq/tools/XmlDataConstants.java |  2 +-
 docs/quickstart-guide/en/examples.md            | 28 +++++-----
 docs/user-manual/en/duplicate-detection.md      |  2 +-
 docs/user-manual/en/filter-expressions.md       | 12 ++--
 docs/user-manual/en/interoperability.md         |  4 +-
 docs/user-manual/en/large-messages.md           | 20 +++----
 docs/user-manual/en/last-value-queues.md        |  6 +-
 docs/user-manual/en/management.md               | 40 +++++++-------
 docs/user-manual/en/message-expiry.md           |  6 +-
 docs/user-manual/en/message-grouping.md         |  6 +-
 docs/user-manual/en/persistence.md              |  2 +-
 docs/user-manual/en/rest.md                     |  4 +-
 docs/user-manual/en/scheduled-messages.md       |  4 +-
 docs/user-manual/en/undelivered-messages.md     |  4 +-
 examples/jms/dead-letter/readme.html            |  4 +-
 .../activemq/jms/example/DeadLetterExample.java |  4 +-
 .../activemq/jms/example/ExpiryExample.java     |  8 +--
 examples/jms/jms-bridge/readme.html             |  2 +-
 .../activemq/jms/example/JMSBridgeExample.java  |  2 +-
 examples/jms/large-message/readme.html          |  4 +-
 .../jms/example/LargeMessageExample.java        |  6 +-
 examples/jms/last-value-queue/readme.html       |  8 +--
 .../jms/example/LastValueQueueExample.java      |  6 +-
 .../jms/management-notifications/readme.html    | 20 +++----
 .../activemq/tests/extras/ExtrasTestLogger.java |  2 +-
 .../byteman/JMSBridgeReconnectionTest.java      |  4 +-
 .../integration/DuplicateDetectionTest.java     |  2 +-
 .../integration/IntegrationTestLogger.java      |  2 +-
 .../integration/client/MessageGroupingTest.java |  2 +-
 .../integration/jms/client/GroupingTest.java    |  2 +-
 .../jms/largemessage/JMSLargeMessageTest.java   | 14 ++---
 .../management/ManagementWithStompTest.java     | 12 ++--
 .../tests/integration/stomp/ExtraStompTest.java |  2 +-
 .../integration/tools/TransferMessageTest.java  |  4 +-
 .../unit/jms/client/SelectorTranslatorTest.java | 58 ++++++++++----------
 55 files changed, 242 insertions(+), 242 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-commons/src/main/java/org/apache/activemq/utils/TypedProperties.java
----------------------------------------------------------------------
diff --git a/activemq-commons/src/main/java/org/apache/activemq/utils/TypedProperties.java b/activemq-commons/src/main/java/org/apache/activemq/utils/TypedProperties.java
index 52e1fd5..098c5c5 100644
--- a/activemq-commons/src/main/java/org/apache/activemq/utils/TypedProperties.java
+++ b/activemq-commons/src/main/java/org/apache/activemq/utils/TypedProperties.java
@@ -52,7 +52,7 @@ import static org.apache.activemq.utils.DataConstants.STRING;
 public final class TypedProperties
 {
 
-   private static final SimpleString HQ_PROPNAME = new SimpleString("_HQ_");
+   private static final SimpleString AMQ_PROPNAME = new SimpleString("_AMQ_");
 
    private Map<SimpleString, PropertyValue> properties;
 
@@ -630,7 +630,7 @@ public final class TypedProperties
             {
                sb.append("[" + ByteUtil.maxString(ByteUtil.bytesToHex((byte [])theValue, 2), 150) + ")");
 
-               if (iterItem.getKey().toString().startsWith("_HQ_ROUTE_TO"))
+               if (iterItem.getKey().toString().startsWith("_AMQ_ROUTE_TO"))
                {
                   sb.append(",bytesAsLongs(");
                   try
@@ -681,7 +681,7 @@ public final class TypedProperties
 
    private synchronized void doPutValue(final SimpleString key, final PropertyValue value)
    {
-      if (key.startsWith(HQ_PROPNAME))
+      if (key.startsWith(AMQ_PROPNAME))
       {
          internalProperties = true;
       }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-core-client/src/main/java/org/apache/activemq/api/core/FilterConstants.java
----------------------------------------------------------------------
diff --git a/activemq-core-client/src/main/java/org/apache/activemq/api/core/FilterConstants.java b/activemq-core-client/src/main/java/org/apache/activemq/api/core/FilterConstants.java
index b23db95..959235b 100644
--- a/activemq-core-client/src/main/java/org/apache/activemq/api/core/FilterConstants.java
+++ b/activemq-core-client/src/main/java/org/apache/activemq/api/core/FilterConstants.java
@@ -25,17 +25,17 @@ public final class FilterConstants
    /**
     * Name of the ActiveMQ UserID header.
     */
-   public static final SimpleString ACTIVEMQ_USERID = new SimpleString("HQUserID");
+   public static final SimpleString ACTIVEMQ_USERID = new SimpleString("AMQUserID");
 
    /**
     * Name of the ActiveMQ Message expiration header.
     */
-   public static final SimpleString ACTIVEMQ_EXPIRATION = new SimpleString("HQExpiration");
+   public static final SimpleString ACTIVEMQ_EXPIRATION = new SimpleString("AMQExpiration");
 
    /**
     * Name of the ActiveMQ Message durable header.
     */
-   public static final SimpleString ACTIVEMQ_DURABLE = new SimpleString("HQDurable");
+   public static final SimpleString ACTIVEMQ_DURABLE = new SimpleString("AMQDurable");
 
    /**
     * Value for the Durable header when the message is non-durable.
@@ -50,22 +50,22 @@ public final class FilterConstants
    /**
     * Name of the ActiveMQ Message timestamp header.
     */
-   public static final SimpleString ACTIVEMQ_TIMESTAMP = new SimpleString("HQTimestamp");
+   public static final SimpleString ACTIVEMQ_TIMESTAMP = new SimpleString("AMQTimestamp");
 
    /**
     * Name of the ActiveMQ Message priority header.
     */
-   public static final SimpleString ACTIVEMQ_PRIORITY = new SimpleString("HQPriority");
+   public static final SimpleString ACTIVEMQ_PRIORITY = new SimpleString("AMQPriority");
 
    /**
     * Name of the ActiveMQ Message size header.
     */
-   public static final SimpleString ACTIVEMQ_SIZE = new SimpleString("HQSize");
+   public static final SimpleString ACTIVEMQ_SIZE = new SimpleString("AMQSize");
 
    /**
     * All ActiveMQ headers are prepended by this prefix.
     */
-   public static final SimpleString ACTIVEMQ_PREFIX = new SimpleString("HQ");
+   public static final SimpleString ACTIVEMQ_PREFIX = new SimpleString("AMQ");
 
    private FilterConstants()
    {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-core-client/src/main/java/org/apache/activemq/api/core/Message.java
----------------------------------------------------------------------
diff --git a/activemq-core-client/src/main/java/org/apache/activemq/api/core/Message.java b/activemq-core-client/src/main/java/org/apache/activemq/api/core/Message.java
index 6ab7f5c..536d3de 100644
--- a/activemq-core-client/src/main/java/org/apache/activemq/api/core/Message.java
+++ b/activemq-core-client/src/main/java/org/apache/activemq/api/core/Message.java
@@ -52,25 +52,25 @@ import org.apache.activemq.utils.UUID;
  */
 public interface Message
 {
-   SimpleString HDR_ACTUAL_EXPIRY_TIME = new SimpleString("_HQ_ACTUAL_EXPIRY");
+   SimpleString HDR_ACTUAL_EXPIRY_TIME = new SimpleString("_AMQ_ACTUAL_EXPIRY");
 
-   SimpleString HDR_ORIGINAL_ADDRESS = new SimpleString("_HQ_ORIG_ADDRESS");
+   SimpleString HDR_ORIGINAL_ADDRESS = new SimpleString("_AMQ_ORIG_ADDRESS");
 
-   SimpleString HDR_ORIGINAL_QUEUE = new SimpleString("_HQ_ORIG_QUEUE");
+   SimpleString HDR_ORIGINAL_QUEUE = new SimpleString("_AMQ_ORIG_QUEUE");
 
-   SimpleString HDR_ORIG_MESSAGE_ID = new SimpleString("_HQ_ORIG_MESSAGE_ID");
+   SimpleString HDR_ORIG_MESSAGE_ID = new SimpleString("_AMQ_ORIG_MESSAGE_ID");
 
-   SimpleString HDR_GROUP_ID = new SimpleString("_HQ_GROUP_ID");
+   SimpleString HDR_GROUP_ID = new SimpleString("_AMQ_GROUP_ID");
 
-   SimpleString HDR_LARGE_COMPRESSED = new SimpleString("_HQ_LARGE_COMPRESSED");
+   SimpleString HDR_LARGE_COMPRESSED = new SimpleString("_AMQ_LARGE_COMPRESSED");
 
-   SimpleString HDR_LARGE_BODY_SIZE = new SimpleString("_HQ_LARGE_SIZE");
+   SimpleString HDR_LARGE_BODY_SIZE = new SimpleString("_AMQ_LARGE_SIZE");
 
-   SimpleString HDR_SCHEDULED_DELIVERY_TIME = new SimpleString("_HQ_SCHED_DELIVERY");
+   SimpleString HDR_SCHEDULED_DELIVERY_TIME = new SimpleString("_AMQ_SCHED_DELIVERY");
 
-   SimpleString HDR_DUPLICATE_DETECTION_ID = new SimpleString("_HQ_DUPL_ID");
+   SimpleString HDR_DUPLICATE_DETECTION_ID = new SimpleString("_AMQ_DUPL_ID");
 
-   SimpleString HDR_LAST_VALUE_NAME = new SimpleString("_HQ_LVQ_NAME");
+   SimpleString HDR_LAST_VALUE_NAME = new SimpleString("_AMQ_LVQ_NAME");
 
    byte DEFAULT_TYPE = 0;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-core-client/src/main/java/org/apache/activemq/api/core/management/ManagementHelper.java
----------------------------------------------------------------------
diff --git a/activemq-core-client/src/main/java/org/apache/activemq/api/core/management/ManagementHelper.java b/activemq-core-client/src/main/java/org/apache/activemq/api/core/management/ManagementHelper.java
index 9dbb962..c73f619 100644
--- a/activemq-core-client/src/main/java/org/apache/activemq/api/core/management/ManagementHelper.java
+++ b/activemq-core-client/src/main/java/org/apache/activemq/api/core/management/ManagementHelper.java
@@ -34,41 +34,41 @@ public final class ManagementHelper
 {
    // Constants -----------------------------------------------------
 
-   public static final SimpleString HDR_RESOURCE_NAME = new SimpleString("_HQ_ResourceName");
+   public static final SimpleString HDR_RESOURCE_NAME = new SimpleString("_AMQ_ResourceName");
 
-   public static final SimpleString HDR_ATTRIBUTE = new SimpleString("_HQ_Attribute");
+   public static final SimpleString HDR_ATTRIBUTE = new SimpleString("_AMQ_Attribute");
 
-   public static final SimpleString HDR_OPERATION_NAME = new SimpleString("_HQ_OperationName");
+   public static final SimpleString HDR_OPERATION_NAME = new SimpleString("_AMQ_OperationName");
 
-   public static final SimpleString HDR_OPERATION_SUCCEEDED = new SimpleString("_HQ_OperationSucceeded");
+   public static final SimpleString HDR_OPERATION_SUCCEEDED = new SimpleString("_AMQ_OperationSucceeded");
 
-   public static final SimpleString HDR_NOTIFICATION_TYPE = new SimpleString("_HQ_NotifType");
+   public static final SimpleString HDR_NOTIFICATION_TYPE = new SimpleString("_AMQ_NotifType");
 
-   public static final SimpleString HDR_NOTIFICATION_TIMESTAMP = new SimpleString("_HQ_NotifTimestamp");
+   public static final SimpleString HDR_NOTIFICATION_TIMESTAMP = new SimpleString("_AMQ_NotifTimestamp");
 
-   public static final SimpleString HDR_ROUTING_NAME = new SimpleString("_HQ_RoutingName");
+   public static final SimpleString HDR_ROUTING_NAME = new SimpleString("_AMQ_RoutingName");
 
-   public static final SimpleString HDR_CLUSTER_NAME = new SimpleString("_HQ_ClusterName");
+   public static final SimpleString HDR_CLUSTER_NAME = new SimpleString("_AMQ_ClusterName");
 
-   public static final SimpleString HDR_ADDRESS = new SimpleString("_HQ_Address");
+   public static final SimpleString HDR_ADDRESS = new SimpleString("_AMQ_Address");
 
-   public static final SimpleString HDR_BINDING_ID = new SimpleString("_HQ_Binding_ID");
+   public static final SimpleString HDR_BINDING_ID = new SimpleString("_AMQ_Binding_ID");
 
-   public static final SimpleString HDR_BINDING_TYPE = new SimpleString("_HQ_Binding_Type");
+   public static final SimpleString HDR_BINDING_TYPE = new SimpleString("_AMQ_Binding_Type");
 
-   public static final SimpleString HDR_FILTERSTRING = new SimpleString("_HQ_FilterString");
+   public static final SimpleString HDR_FILTERSTRING = new SimpleString("_AMQ_FilterString");
 
-   public static final SimpleString HDR_DISTANCE = new SimpleString("_HQ_Distance");
+   public static final SimpleString HDR_DISTANCE = new SimpleString("_AMQ_Distance");
 
-   public static final SimpleString HDR_CONSUMER_COUNT = new SimpleString("_HQ_ConsumerCount");
+   public static final SimpleString HDR_CONSUMER_COUNT = new SimpleString("_AMQ_ConsumerCount");
 
-   public static final SimpleString HDR_USER = new SimpleString("_HQ_User");
+   public static final SimpleString HDR_USER = new SimpleString("_AMQ_User");
 
-   public static final SimpleString HDR_CHECK_TYPE = new SimpleString("_HQ_CheckType");
+   public static final SimpleString HDR_CHECK_TYPE = new SimpleString("_AMQ_CheckType");
 
-   public static final SimpleString HDR_SESSION_NAME = new SimpleString("_HQ_SessionName");
+   public static final SimpleString HDR_SESSION_NAME = new SimpleString("_AMQ_SessionName");
 
-   public static final SimpleString HDR_REMOTE_ADDRESS = new SimpleString("_HQ_RemoteAddress");
+   public static final SimpleString HDR_REMOTE_ADDRESS = new SimpleString("_AMQ_RemoteAddress");
 
    public static final SimpleString HDR_PROPOSAL_GROUP_ID = new SimpleString("_JBM_ProposalGroupId");
 
@@ -76,9 +76,9 @@ public final class ManagementHelper
 
    public static final SimpleString HDR_PROPOSAL_ALT_VALUE = new SimpleString("_JBM_ProposalAltValue");
 
-   public static final SimpleString HDR_CONSUMER_NAME = new SimpleString("_HQ_ConsumerName");
+   public static final SimpleString HDR_CONSUMER_NAME = new SimpleString("_AMQ_ConsumerName");
 
-   public static final SimpleString HDR_CONNECTION_NAME = new SimpleString("_HQ_ConnectionName");
+   public static final SimpleString HDR_CONNECTION_NAME = new SimpleString("_AMQ_ConnectionName");
 
    // Attributes ----------------------------------------------------
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-core-client/src/main/java/org/apache/activemq/core/message/impl/MessageImpl.java
----------------------------------------------------------------------
diff --git a/activemq-core-client/src/main/java/org/apache/activemq/core/message/impl/MessageImpl.java b/activemq-core-client/src/main/java/org/apache/activemq/core/message/impl/MessageImpl.java
index b16946c..4490fc2 100644
--- a/activemq-core-client/src/main/java/org/apache/activemq/core/message/impl/MessageImpl.java
+++ b/activemq-core-client/src/main/java/org/apache/activemq/core/message/impl/MessageImpl.java
@@ -42,14 +42,14 @@ import org.apache.activemq.utils.UUID;
  */
 public abstract class MessageImpl implements MessageInternal
 {
-   public static final SimpleString HDR_ROUTE_TO_IDS = new SimpleString("_HQ_ROUTE_TO");
+   public static final SimpleString HDR_ROUTE_TO_IDS = new SimpleString("_AMQ_ROUTE_TO");
 
-   public static final SimpleString HDR_SCALEDOWN_TO_IDS = new SimpleString("_HQ_SCALEDOWN_TO");
+   public static final SimpleString HDR_SCALEDOWN_TO_IDS = new SimpleString("_AMQ_SCALEDOWN_TO");
 
-   public static final SimpleString HDR_ROUTE_TO_ACK_IDS = new SimpleString("_HQ_ACK_ROUTE_TO");
+   public static final SimpleString HDR_ROUTE_TO_ACK_IDS = new SimpleString("_AMQ_ACK_ROUTE_TO");
 
    // used by the bridges to set duplicates
-   public static final SimpleString HDR_BRIDGE_DUPLICATE_ID = new SimpleString("_HQ_BRIDGE_DUP");
+   public static final SimpleString HDR_BRIDGE_DUPLICATE_ID = new SimpleString("_AMQ_BRIDGE_DUP");
 
    public static final int BUFFER_HEADER_SPACE = PacketImpl.PACKET_HEADERS_SIZE;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-core-client/src/main/java/org/apache/activemq/reader/MessageUtil.java
----------------------------------------------------------------------
diff --git a/activemq-core-client/src/main/java/org/apache/activemq/reader/MessageUtil.java b/activemq-core-client/src/main/java/org/apache/activemq/reader/MessageUtil.java
index 29eab1e..0b795f5 100644
--- a/activemq-core-client/src/main/java/org/apache/activemq/reader/MessageUtil.java
+++ b/activemq-core-client/src/main/java/org/apache/activemq/reader/MessageUtil.java
@@ -50,7 +50,7 @@ public class MessageUtil
 
    public static final String JMSXGROUPID = "JMSXGroupID";
 
-   public static final SimpleString CONNECTION_ID_PROPERTY_NAME = new SimpleString("__HQ_CID");
+   public static final SimpleString CONNECTION_ID_PROPERTY_NAME = new SimpleString("__AMQ_CID");
 
 
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-jms-client/src/main/java/org/apache/activemq/api/jms/ActiveMQJMSConstants.java
----------------------------------------------------------------------
diff --git a/activemq-jms-client/src/main/java/org/apache/activemq/api/jms/ActiveMQJMSConstants.java b/activemq-jms-client/src/main/java/org/apache/activemq/api/jms/ActiveMQJMSConstants.java
index 35284ed..104645f 100644
--- a/activemq-jms-client/src/main/java/org/apache/activemq/api/jms/ActiveMQJMSConstants.java
+++ b/activemq-jms-client/src/main/java/org/apache/activemq/api/jms/ActiveMQJMSConstants.java
@@ -21,13 +21,13 @@ package org.apache.activemq.api.jms;
  */
 public class ActiveMQJMSConstants
 {
-   public static final String JMS_ACTIVEMQ_INPUT_STREAM = "JMS_HQ_InputStream";
+   public static final String JMS_ACTIVEMQ_INPUT_STREAM = "JMS_AMQ_InputStream";
 
-   public static final String JMS_ACTIVEMQ_OUTPUT_STREAM = "JMS_HQ_OutputStream";
+   public static final String JMS_ACTIVEMQ_OUTPUT_STREAM = "JMS_AMQ_OutputStream";
 
-   public static final String JMS_ACTIVEMQ_SAVE_STREAM = "JMS_HQ_SaveStream";
+   public static final String JMS_ACTIVEMQ_SAVE_STREAM = "JMS_AMQ_SaveStream";
 
-   public static final String JBOSS_MESSAGING_BRIDGE_MESSAGE_ID_LIST = "HQ_BRIDGE_MSG_ID_LIST";
+   public static final String AMQ_MESSAGING_BRIDGE_MESSAGE_ID_LIST = "AMQ_BRIDGE_MSG_ID_LIST";
 
    public static final int PRE_ACKNOWLEDGE = 100;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/ActiveMQSession.java
----------------------------------------------------------------------
diff --git a/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/ActiveMQSession.java b/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/ActiveMQSession.java
index 26a151a..c409c27 100644
--- a/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/ActiveMQSession.java
+++ b/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/ActiveMQSession.java
@@ -74,7 +74,7 @@ public class ActiveMQSession implements QueueSession, TopicSession
 
    public static final int TYPE_TOPIC_SESSION = 2;
 
-   private static SimpleString REJECTING_FILTER = new SimpleString("_HQX=-1");
+   private static SimpleString REJECTING_FILTER = new SimpleString("_AMQX=-1");
 
    private final ActiveMQConnection connection;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/SelectorTranslator.java
----------------------------------------------------------------------
diff --git a/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/SelectorTranslator.java b/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/SelectorTranslator.java
index e98da0f..1c28bf1 100644
--- a/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/SelectorTranslator.java
+++ b/activemq-jms-client/src/main/java/org/apache/activemq/jms/client/SelectorTranslator.java
@@ -44,13 +44,13 @@ public class SelectorTranslator
 
       // First convert any JMS header identifiers
 
-      String filterString = SelectorTranslator.parse(selectorString, "JMSDeliveryMode", "HQDurable");
+      String filterString = SelectorTranslator.parse(selectorString, "JMSDeliveryMode", "AMQDurable");
       filterString = SelectorTranslator.parse(filterString, "'PERSISTENT'", "'DURABLE'");
       filterString = SelectorTranslator.parse(filterString, "'NON_PERSISTENT'", "'NON_DURABLE'");
-      filterString = SelectorTranslator.parse(filterString, "JMSPriority", "HQPriority");
-      filterString = SelectorTranslator.parse(filterString, "JMSTimestamp", "HQTimestamp");
-      filterString = SelectorTranslator.parse(filterString, "JMSMessageID", "HQUserID");
-      filterString = SelectorTranslator.parse(filterString, "JMSExpiration", "HQExpiration");
+      filterString = SelectorTranslator.parse(filterString, "JMSPriority", "AMQPriority");
+      filterString = SelectorTranslator.parse(filterString, "JMSTimestamp", "AMQTimestamp");
+      filterString = SelectorTranslator.parse(filterString, "JMSMessageID", "AMQUserID");
+      filterString = SelectorTranslator.parse(filterString, "JMSExpiration", "AMQExpiration");
 
       return filterString;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-jms-server/src/main/java/org/apache/activemq/jms/bridge/impl/JMSBridgeImpl.java
----------------------------------------------------------------------
diff --git a/activemq-jms-server/src/main/java/org/apache/activemq/jms/bridge/impl/JMSBridgeImpl.java b/activemq-jms-server/src/main/java/org/apache/activemq/jms/bridge/impl/JMSBridgeImpl.java
index a7facc4..9feb528 100644
--- a/activemq-jms-server/src/main/java/org/apache/activemq/jms/bridge/impl/JMSBridgeImpl.java
+++ b/activemq-jms-server/src/main/java/org/apache/activemq/jms/bridge/impl/JMSBridgeImpl.java
@@ -1785,7 +1785,7 @@ public final class JMSBridgeImpl implements JMSBridge
 
       String val = null;
 
-      val = msg.getStringProperty(ActiveMQJMSConstants.JBOSS_MESSAGING_BRIDGE_MESSAGE_ID_LIST);
+      val = msg.getStringProperty(ActiveMQJMSConstants.AMQ_MESSAGING_BRIDGE_MESSAGE_ID_LIST);
 
       if (val == null)
       {
@@ -1800,7 +1800,7 @@ public final class JMSBridgeImpl implements JMSBridge
          val = sb.toString();
       }
 
-      msg.setStringProperty(ActiveMQJMSConstants.JBOSS_MESSAGING_BRIDGE_MESSAGE_ID_LIST, val);
+      msg.setStringProperty(ActiveMQJMSConstants.AMQ_MESSAGING_BRIDGE_MESSAGE_ID_LIST, val);
    }
 
    /*

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-protocols/activemq-openwire-protocol/src/main/java/org/apache/activemq/core/protocol/openwire/OpenWireMessageConverter.java
----------------------------------------------------------------------
diff --git a/activemq-protocols/activemq-openwire-protocol/src/main/java/org/apache/activemq/core/protocol/openwire/OpenWireMessageConverter.java b/activemq-protocols/activemq-openwire-protocol/src/main/java/org/apache/activemq/core/protocol/openwire/OpenWireMessageConverter.java
index c1eb72b..85dad42 100644
--- a/activemq-protocols/activemq-openwire-protocol/src/main/java/org/apache/activemq/core/protocol/openwire/OpenWireMessageConverter.java
+++ b/activemq-protocols/activemq-openwire-protocol/src/main/java/org/apache/activemq/core/protocol/openwire/OpenWireMessageConverter.java
@@ -763,7 +763,7 @@ public class OpenWireMessageConverter implements MessageConverter
          for (SimpleString s : props)
          {
             String keyStr = s.toString();
-            if (keyStr.startsWith("__HQ") || keyStr.startsWith("__HDR_"))
+            if (keyStr.startsWith("__AMQ") || keyStr.startsWith("__HDR_"))
             {
                continue;
             }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-protocols/activemq-stomp-protocol/src/main/java/org/apache/activemq/core/protocol/stomp/StompConnection.java
----------------------------------------------------------------------
diff --git a/activemq-protocols/activemq-stomp-protocol/src/main/java/org/apache/activemq/core/protocol/stomp/StompConnection.java b/activemq-protocols/activemq-stomp-protocol/src/main/java/org/apache/activemq/core/protocol/stomp/StompConnection.java
index d4bd578..26ce7cd 100644
--- a/activemq-protocols/activemq-stomp-protocol/src/main/java/org/apache/activemq/core/protocol/stomp/StompConnection.java
+++ b/activemq-protocols/activemq-stomp-protocol/src/main/java/org/apache/activemq/core/protocol/stomp/StompConnection.java
@@ -48,7 +48,7 @@ import static org.apache.activemq.core.protocol.stomp.ActiveMQStompProtocolMessa
 
 public final class StompConnection implements RemotingConnection
 {
-   protected static final String CONNECTION_ID_PROP = "__HQ_CID";
+   protected static final String CONNECTION_ID_PROP = "__AMQ_CID";
    private static final String SERVER_NAME = "ActiveMQ/" + VersionLoader.getVersion().getFullVersion() +
       " ActiveMQ Messaging Engine";
 
@@ -633,7 +633,7 @@ public final class StompConnection implements RemotingConnection
       }
       if (enableMessageID())
       {
-         message.putStringProperty("hqMessageId",
+         message.putStringProperty("amqMessageId",
                                    "STOMP" + message.getMessageID());
       }
       try

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-rest/src/main/java/org/apache/activemq/rest/topic/TopicDestinationsResource.java
----------------------------------------------------------------------
diff --git a/activemq-rest/src/main/java/org/apache/activemq/rest/topic/TopicDestinationsResource.java b/activemq-rest/src/main/java/org/apache/activemq/rest/topic/TopicDestinationsResource.java
index 25d917c..1539610 100644
--- a/activemq-rest/src/main/java/org/apache/activemq/rest/topic/TopicDestinationsResource.java
+++ b/activemq-rest/src/main/java/org/apache/activemq/rest/topic/TopicDestinationsResource.java
@@ -72,7 +72,7 @@ public class TopicDestinationsResource
             ClientSession.QueueQuery query = session.queueQuery(new SimpleString(topicName));
             if (!query.isExists())
             {
-               session.createQueue(topicName, topicName, "__HQX=-1", true);
+               session.createQueue(topicName, topicName, "__AMQX=-1", true);
 
             }
             else

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/main/java/org/apache/activemq/core/filter/impl/FilterImpl.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/main/java/org/apache/activemq/core/filter/impl/FilterImpl.java b/activemq-server/src/main/java/org/apache/activemq/core/filter/impl/FilterImpl.java
index 93c51ad..dd03532 100644
--- a/activemq-server/src/main/java/org/apache/activemq/core/filter/impl/FilterImpl.java
+++ b/activemq-server/src/main/java/org/apache/activemq/core/filter/impl/FilterImpl.java
@@ -35,12 +35,12 @@ import org.apache.activemq.core.server.ServerMessage;
 *
 * Valid identifiers that can be used are:
 *
-* HQPriority - the priority of the message
-* HQTimestamp - the timestamp of the message
-* HQDurable - "DURABLE" or "NON_DURABLE"
-* HQExpiration - the expiration of the message
-* HQSize - the encoded size of the full message in bytes
-* HQUserID - the user specified ID string (if any)
+* AMQPriority - the priority of the message
+* AMQTimestamp - the timestamp of the message
+* AMQDurable - "DURABLE" or "NON_DURABLE"
+* AMQExpiration - the expiration of the message
+* AMQSize - the encoded size of the full message in bytes
+* AMQUserID - the user specified ID string (if any)
 * Any other identifiers that appear in a filter expression represent header values for the message
 *
 * String values must be set as <code>SimpleString</code>, not <code>java.lang.String</code> (see JBMESSAGING-1307).

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/main/java/org/apache/activemq/core/postoffice/impl/PostOfficeImpl.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/main/java/org/apache/activemq/core/postoffice/impl/PostOfficeImpl.java b/activemq-server/src/main/java/org/apache/activemq/core/postoffice/impl/PostOfficeImpl.java
index 2a60d03..1c8c811 100644
--- a/activemq-server/src/main/java/org/apache/activemq/core/postoffice/impl/PostOfficeImpl.java
+++ b/activemq-server/src/main/java/org/apache/activemq/core/postoffice/impl/PostOfficeImpl.java
@@ -85,9 +85,9 @@ public class PostOfficeImpl implements PostOffice, NotificationListener, Binding
 {
    private static final boolean isTrace = ActiveMQServerLogger.LOGGER.isTraceEnabled();
 
-   public static final SimpleString HDR_RESET_QUEUE_DATA = new SimpleString("_HQ_RESET_QUEUE_DATA");
+   public static final SimpleString HDR_RESET_QUEUE_DATA = new SimpleString("_AMQ_RESET_QUEUE_DATA");
 
-   public static final SimpleString HDR_RESET_QUEUE_DATA_COMPLETE = new SimpleString("_HQ_RESET_QUEUE_DATA_COMPLETE");
+   public static final SimpleString HDR_RESET_QUEUE_DATA_COMPLETE = new SimpleString("_AMQ_RESET_QUEUE_DATA_COMPLETE");
 
    public static final SimpleString BRIDGE_CACHE_STR = new SimpleString("BRIDGE.");
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/main/java/org/apache/activemq/core/server/ServerMessage.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/main/java/org/apache/activemq/core/server/ServerMessage.java b/activemq-server/src/main/java/org/apache/activemq/core/server/ServerMessage.java
index f3ceaee..dac23f9 100644
--- a/activemq-server/src/main/java/org/apache/activemq/core/server/ServerMessage.java
+++ b/activemq-server/src/main/java/org/apache/activemq/core/server/ServerMessage.java
@@ -64,7 +64,7 @@ public interface ServerMessage extends MessageInternal, EncodingSupport
 
    PagingStore getPagingStore();
 
-   // Is there any _HQ_ property being used
+   // Is there any _AMQ_ property being used
    boolean hasInternalProperties();
 
    boolean storeIsPaging();

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ActiveMQServerImpl.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ActiveMQServerImpl.java b/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ActiveMQServerImpl.java
index a56e085..973f3e1 100644
--- a/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ActiveMQServerImpl.java
+++ b/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ActiveMQServerImpl.java
@@ -144,7 +144,7 @@ public class ActiveMQServerImpl implements ActiveMQServer
     * any other component on the system, and just be ignored for any purpose It's declared here as
     * this filter is considered a global ignore
     */
-   public static final String GENERIC_IGNORED_FILTER = "__HQX=-1";
+   public static final String GENERIC_IGNORED_FILTER = "__AMQX=-1";
 
    private HAPolicy haPolicy;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ScaleDownHandler.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ScaleDownHandler.java b/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ScaleDownHandler.java
index f5f87f9..adc2fc5 100644
--- a/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ScaleDownHandler.java
+++ b/activemq-server/src/main/java/org/apache/activemq/core/server/impl/ScaleDownHandler.java
@@ -282,8 +282,8 @@ public class ScaleDownHandler
                Message message = messageRef.getMessage().copy();
 
                /* Here we are taking messages out of a store-and-forward queue and sending them to the corresponding
-                * address on the scale-down target server.  However, we have to take the existing _HQ_ROUTE_TOsf.*
-                * property and put its value into the _HQ_ROUTE_TO property so the message is routed properly.
+                * address on the scale-down target server.  However, we have to take the existing _AMQ_ROUTE_TOsf.*
+                * property and put its value into the _AMQ_ROUTE_TO property so the message is routed properly.
                 */
 
                byte[] oldRouteToIDs = null;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-server/src/test/java/org/apache/activemq/core/filter/impl/FilterTest.java
----------------------------------------------------------------------
diff --git a/activemq-server/src/test/java/org/apache/activemq/core/filter/impl/FilterTest.java b/activemq-server/src/test/java/org/apache/activemq/core/filter/impl/FilterTest.java
index 658f865..dcbfd67 100644
--- a/activemq-server/src/test/java/org/apache/activemq/core/filter/impl/FilterTest.java
+++ b/activemq-server/src/test/java/org/apache/activemq/core/filter/impl/FilterTest.java
@@ -86,9 +86,9 @@ public class FilterTest extends SilentTestCase
    }
 
    @Test
-   public void testHQDurable() throws Exception
+   public void testAMQDurable() throws Exception
    {
-      filter = FilterImpl.createFilter(new SimpleString("HQDurable='DURABLE'"));
+      filter = FilterImpl.createFilter(new SimpleString("AMQDurable='DURABLE'"));
 
       message.setDurable(true);
 
@@ -98,7 +98,7 @@ public class FilterTest extends SilentTestCase
 
       Assert.assertFalse(filter.match(message));
 
-      filter = FilterImpl.createFilter(new SimpleString("HQDurable='NON_DURABLE'"));
+      filter = FilterImpl.createFilter(new SimpleString("AMQDurable='NON_DURABLE'"));
 
       message = new ServerMessageImpl();
       message.setDurable(true);
@@ -112,17 +112,17 @@ public class FilterTest extends SilentTestCase
    }
 
    @Test
-   public void testHQSize() throws Exception
+   public void testAMQSize() throws Exception
    {
       message.setAddress(RandomUtil.randomSimpleString());
 
       int encodeSize = message.getEncodeSize();
 
-      Filter moreThanSmall = FilterImpl.createFilter(new SimpleString("HQSize > " + (encodeSize - 1)));
-      Filter lessThanLarge = FilterImpl.createFilter(new SimpleString("HQSize < " + (encodeSize + 1)));
+      Filter moreThanSmall = FilterImpl.createFilter(new SimpleString("AMQSize > " + (encodeSize - 1)));
+      Filter lessThanLarge = FilterImpl.createFilter(new SimpleString("AMQSize < " + (encodeSize + 1)));
 
-      Filter lessThanSmall = FilterImpl.createFilter(new SimpleString("HQSize < " + encodeSize));
-      Filter moreThanLarge = FilterImpl.createFilter(new SimpleString("HQSize > " + encodeSize));
+      Filter lessThanSmall = FilterImpl.createFilter(new SimpleString("AMQSize < " + encodeSize));
+      Filter moreThanLarge = FilterImpl.createFilter(new SimpleString("AMQSize > " + encodeSize));
 
       Assert.assertTrue(moreThanSmall.match(message));
       Assert.assertTrue(lessThanLarge.match(message));
@@ -133,9 +133,9 @@ public class FilterTest extends SilentTestCase
    }
 
    @Test
-   public void testHQPriority() throws Exception
+   public void testAMQPriority() throws Exception
    {
-      filter = FilterImpl.createFilter(new SimpleString("HQPriority=3"));
+      filter = FilterImpl.createFilter(new SimpleString("AMQPriority=3"));
 
       for (int i = 0; i < 10; i++)
       {
@@ -153,9 +153,9 @@ public class FilterTest extends SilentTestCase
    }
 
    @Test
-   public void testHQTimestamp() throws Exception
+   public void testAMQTimestamp() throws Exception
    {
-      filter = FilterImpl.createFilter(new SimpleString("HQTimestamp=12345678"));
+      filter = FilterImpl.createFilter(new SimpleString("AMQTimestamp=12345678"));
 
       message.setTimestamp(87654321);
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-tools/src/main/java/org/apache/activemq/tools/TransferQueue.java
----------------------------------------------------------------------
diff --git a/activemq-tools/src/main/java/org/apache/activemq/tools/TransferQueue.java b/activemq-tools/src/main/java/org/apache/activemq/tools/TransferQueue.java
index 819406b..e8ee457 100644
--- a/activemq-tools/src/main/java/org/apache/activemq/tools/TransferQueue.java
+++ b/activemq-tools/src/main/java/org/apache/activemq/tools/TransferQueue.java
@@ -149,16 +149,16 @@ public class TransferQueue // NO_UCD (unused code)
 
             message.acknowledge();
 
-            if (!message.containsProperty("_HQ_TOOL_original_address"))
+            if (!message.containsProperty("_AMQ_TOOL_original_address"))
             {
-               message.putStringProperty("_HQ_TOOL_original_address", message.getAddress().toString());
+               message.putStringProperty("_AMQ_TOOL_original_address", message.getAddress().toString());
             }
 
             LinkedList<String> listToRemove = new LinkedList<String>();
 
             for (SimpleString name : message.getPropertyNames())
             {
-               if (name.toString().startsWith("_HQ_ROUTE_TO"))
+               if (name.toString().startsWith("_AMQ_ROUTE_TO"))
                {
                   listToRemove.add(name.toString());
                }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/activemq-tools/src/main/java/org/apache/activemq/tools/XmlDataConstants.java
----------------------------------------------------------------------
diff --git a/activemq-tools/src/main/java/org/apache/activemq/tools/XmlDataConstants.java b/activemq-tools/src/main/java/org/apache/activemq/tools/XmlDataConstants.java
index 1da4891..8881df1 100644
--- a/activemq-tools/src/main/java/org/apache/activemq/tools/XmlDataConstants.java
+++ b/activemq-tools/src/main/java/org/apache/activemq/tools/XmlDataConstants.java
@@ -119,5 +119,5 @@ public final class XmlDataConstants
 
    public static final String JNDI_COMPATIBILITY_PREFIX = "java:jboss/exported/";
 
-   static final String NULL = "_HQ_NULL";
+   static final String NULL = "_AMQ_NULL";
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/quickstart-guide/en/examples.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/examples.md b/docs/quickstart-guide/en/examples.md
index 375df7b..2844de9 100644
--- a/docs/quickstart-guide/en/examples.md
+++ b/docs/quickstart-guide/en/examples.md
@@ -83,27 +83,27 @@ Type the command `mvn verify` and you should see the following output:
     [INFO] --- activemq-maven-plugin:1.1.1-SNAPSHOT:start (start) @ activemq-jms-queue-example ---
     [file:/home/andy/projects/activemq-master/examples/jms/queue/target/classes/activemq/server0/]
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.deployers.impl.FileConfigurationParser parseMainConfig
-    WARN: HQ222018: AIO was not located on this platform, it will fall back to using pure Java NIO. If your platform is Linux, install LibAIO to enable the AIO journal
+    WARN: AMQ222018: AIO was not located on this platform, it will fall back to using pure Java NIO. If your platform is Linux, install LibAIO to enable the AIO journal
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl start
-    INFO: HQ221000: live server is starting with configuration ActiveMQ Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/journal,bindingsDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/bindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/largemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/paging)
+    INFO: AMQ221000: live server is starting with configuration ActiveMQ Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/journal,bindingsDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/bindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/largemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/paging)
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl$SharedStoreLiveActivation run
-    INFO: HQ221006: Waiting to obtain live lock
+    INFO: AMQ221006: Waiting to obtain live lock
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.persistence.impl.journal.JournalStorageManager <init>
-    INFO: HQ221013: Using NIO Journal
+    INFO: AMQ221013: Using NIO Journal
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl initialisePart1
-    WARN: HQ222007: Security risk! ActiveMQ is running with the default cluster admin user and default password. Please see the ActiveMQ user guide, cluster chapter, for instructions on how to change this.
+    WARN: AMQ222007: Security risk! ActiveMQ is running with the default cluster admin user and default password. Please see the ActiveMQ user guide, cluster chapter, for instructions on how to change this.
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.FileLockNodeManager startLiveNode
-    INFO: HQ221034: Waiting to obtain live lock
+    INFO: AMQ221034: Waiting to obtain live lock
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.FileLockNodeManager startLiveNode
-    INFO: HQ221035: Live Server Obtained live lock
+    INFO: AMQ221035: Live Server Obtained live lock
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl deployQueue
-    INFO: HQ221003: trying to deploy queue jms.queue.exampleQueue
+    INFO: AMQ221003: trying to deploy queue jms.queue.exampleQueue
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.remoting.impl.netty.NettyAcceptor start
-    INFO: HQ221020: Started Netty Acceptor version 3.6.2.Final-c0d783c localhost:61616 for CORE protocol
+    INFO: AMQ221020: Started Netty Acceptor version 3.6.2.Final-c0d783c localhost:61616 for CORE protocol
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl$SharedStoreLiveActivation run
-    INFO: HQ221007: Server is now live
+    INFO: AMQ221007: Server is now live
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl start
-    INFO: HQ221001: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7]
+    INFO: AMQ221001: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7]
     [INFO]
     [INFO] --- activemq-maven-plugin:1.1.1-SNAPSHOT:runClient (runClient) @ activemq-jms-queue-example ---
     Apr 17, 2013 10:51:02 AM org.apache.activemq.common.example.ActiveMQExample getContext
@@ -118,9 +118,9 @@ Type the command `mvn verify` and you should see the following output:
     [INFO]
     [INFO] --- activemq-maven-plugin:1.1.1-SNAPSHOT:stop (stop) @ activemq-jms-queue-example ---
     Apr 17, 2013 10:51:03 AM org.apache.activemq.core.server.management.impl.ManagementServiceImpl stop
-    WARN: HQ222113: On ManagementService stop, there are 1 unexpected registered MBeans: [core.acceptor.netty-acceptor]
+    WARN: AMQ222113: On ManagementService stop, there are 1 unexpected registered MBeans: [core.acceptor.netty-acceptor]
     Apr 17, 2013 10:51:03 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl stop
-    INFO: HQ221002: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7] stopped
+    INFO: AMQ221002: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7] stopped
     [INFO] ------------------------------------------------------------------------
     [INFO] BUILD SUCCESS
     [INFO] ------------------------------------------------------------------------
@@ -233,7 +233,7 @@ In the shell window you should see something like the following output:
     10:58:08,790 INFO  [org.apache.activemq.core.remoting.impl.netty.NettyAcceptor] (MSC service thread 1-11) Started Netty Acceptor version 3.2.5.Final-a96d88c localhost.localdomain:61616 for CORE protocol
     10:58:08,793 INFO  [org.apache.activemq.core.remoting.impl.netty.NettyAcceptor] (MSC service thread 1-11) Started Netty Acceptor version 3.2.5.Final-a96d88c localhost.localdomain:5455 for CORE protocol
     10:58:08,795 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) Server is now live
-    10:58:08,797 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) ActiveMQ Server version 2.2.13.Final (HQ_2_2_13_FINAL_AS7, 122) [5c499e88-9c63-11e2-bfa3-fe5400591699]) started
+    10:58:08,797 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) ActiveMQ Server version 2.2.13.Final (AMQ_2_2_13_FINAL_AS7, 122) [5c499e88-9c63-11e2-bfa3-fe5400591699]) started
     10:58:08,822 INFO  [org.jboss.as.messaging] (MSC service thread 1-4) JBAS011601: Bound messaging object to jndi name java:jboss/exported/jms/RemoteConnectionFactory
     10:58:08,824 INFO  [org.jboss.as.messaging] (MSC service thread 1-4) JBAS011601: Bound messaging object to jndi name java:/RemoteConnectionFactory
     10:58:08,825 INFO  [org.jboss.as.messaging] (MSC service thread 1-10) JBAS011601: Bound messaging object to jndi name java:/ConnectionFactory

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/duplicate-detection.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/duplicate-detection.md b/docs/user-manual/en/duplicate-detection.md
index eeb4eaf..e02fcaf 100644
--- a/docs/user-manual/en/duplicate-detection.md
+++ b/docs/user-manual/en/duplicate-detection.md
@@ -64,7 +64,7 @@ ignore the entire transaction.
 
 The name of the property that you set is given by the value of
 `org.apache.activemq.api.core.Message.HDR_DUPLICATE_DETECTION_ID`, which
-is `_HQ_DUPL_ID`
+is `_AMQ_DUPL_ID`
 
 The value of the property can be of type `byte[]` or `SimpleString` if
 you're using the core API. If you're using JMS it must be a `String`,

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/filter-expressions.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/filter-expressions.md b/docs/user-manual/en/filter-expressions.md
index 61736fb..4375dc0 100644
--- a/docs/user-manual/en/filter-expressions.md
+++ b/docs/user-manual/en/filter-expressions.md
@@ -31,21 +31,21 @@ JMS message, Apache ActiveMQ core filter expressions operate on a core message.
 The following identifiers can be used in a core filter expressions to
 refer to attributes of the core message in an expression:
 
--   `HQPriority`. To refer to the priority of a message. Message
+-   `AMQPriority`. To refer to the priority of a message. Message
     priorities are integers with valid values from `0 - 9`. `0` is the
     lowest priority and `9` is the highest. E.g.
-    `HQPriority = 3 AND animal = 'aardvark'`
+    `AMQPriority = 3 AND animal = 'aardvark'`
 
--   `HQExpiration`. To refer to the expiration time of a message. The
+-   `AMQExpiration`. To refer to the expiration time of a message. The
     value is a long integer.
 
--   `HQDurable`. To refer to whether a message is durable or not. The
+-   `AMQDurable`. To refer to whether a message is durable or not. The
     value is a string with valid values: `DURABLE` or `NON_DURABLE`.
 
--   `HQTimestamp`. The timestamp of when the message was created. The
+-   `AMQTimestamp`. The timestamp of when the message was created. The
     value is a long integer.
 
--   `HQSize`. The size of a message in bytes. The value is an integer.
+-   `AMQSize`. The size of a message in bytes. The value is an integer.
 
 Any other identifiers used in core filter expressions will be assumed to
 be properties of the message.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/interoperability.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/interoperability.md b/docs/user-manual/en/interoperability.md
index 1b02245..3ce1102 100644
--- a/docs/user-manual/en/interoperability.md
+++ b/docs/user-manual/en/interoperability.md
@@ -156,10 +156,10 @@ unique ID, just set the `stompEnableMessageId` to true. For example:
 When the server starts with the above setting, each stomp message sent
 through this acceptor will have an extra property added. The property
 key is `
-            hq-message-id` and the value is a String representation of a
+            amq-message-id` and the value is a String representation of a
 long type internal message id prefixed with "`STOMP`", like:
 
-    hq-message-id : STOMP12345
+    amq-message-id : STOMP12345
 
 If `stomp-enable-message-id` is not specified in the configuration,
 default is `false`.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/large-messages.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/large-messages.md b/docs/user-manual/en/large-messages.md
index 403bffb..373f1e4 100644
--- a/docs/user-manual/en/large-messages.md
+++ b/docs/user-manual/en/large-messages.md
@@ -167,17 +167,17 @@ which are also available through JMS by the use of object properties.
     <tr>
         <td>setBodyInputStream(InputStream)</td>
         <td>Set the InputStream used to read a message body when sending it.</td>
-        <td>JMS_HQ_InputStream</td>
+        <td>JMS_AMQ_InputStream</td>
     </tr>
     <tr>
         <td>setOutputStream(OutputStream)</td>
         <td>Set the OutputStream that will receive the body of a message. This method does not block.</td>
-        <td>JMS_HQ_OutputStream</td>
+        <td>JMS_AMQ_OutputStream</td>
     </tr>
     <tr>
         <td>saveOutputStream(OutputStream)</td>
         <td>Save the body of the message to the `OutputStream`. It will block until the entire content is transferred to the `OutputStream`.</td>
-        <td>JMS_HQ_SaveStream</td>
+        <td>JMS_AMQ_SaveStream</td>
     </tr>
     </tbody>
 </table>
@@ -209,7 +209,7 @@ msg.setInputStream(dataInputStream);
 Notice also that for messages with more than 2GiB the getBodySize() will
 return invalid values since this is an integer (which is also exposed to
 the JMS API). On those cases you can use the message property
-_HQ_LARGE_SIZE.
+_AMQ_LARGE_SIZE.
 
 ### Streaming over JMS
 
@@ -218,7 +218,7 @@ ClientMessage API table above) by setting object properties . You can use the me
 `Message.setObjectProperty` to set the input and output streams.
 
 The `InputStream` can be defined through the JMS Object Property
-JMS_HQ_InputStream on messages being sent:
+JMS_AMQ_InputStream on messages being sent:
 
 ``` java
 BytesMessage message = session.createBytesMessage();
@@ -227,13 +227,13 @@ FileInputStream fileInputStream = new FileInputStream(fileInput);
 
 BufferedInputStream bufferedInput = new BufferedInputStream(fileInputStream);
 
-message.setObjectProperty("JMS_HQ_InputStream", bufferedInput);
+message.setObjectProperty("JMS_AMQ_InputStream", bufferedInput);
 
 someProducer.send(message);
 ```
 
 The `OutputStream` can be set through the JMS Object Property
-JMS_HQ_SaveStream on messages being received in a blocking way.
+JMS_AMQ_SaveStream on messages being received in a blocking way.
 
 ``` java
 BytesMessage messageReceived = (BytesMessage)messageConsumer.receive(120000);
@@ -245,15 +245,15 @@ FileOutputStream fileOutputStream = new FileOutputStream(outputFile);
 BufferedOutputStream bufferedOutput = new BufferedOutputStream(fileOutputStream);
 
 // This will block until the entire content is saved on disk
-messageReceived.setObjectProperty("JMS_HQ_SaveStream", bufferedOutput);
+messageReceived.setObjectProperty("JMS_AMQ_SaveStream", bufferedOutput);
 ```
 
 Setting the `OutputStream` could also be done in a non blocking way
-using the property JMS_HQ_OutputStream.
+using the property JMS_AMQ_OutputStream.
 
 ``` java
 // This won't wait the stream to finish. You need to keep the consumer active.
-messageReceived.setObjectProperty("JMS_HQ_OutputStream", bufferedOutput);
+messageReceived.setObjectProperty("JMS_AMQ_OutputStream", bufferedOutput);
 ```
 
 > **Note**

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/last-value-queues.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/last-value-queues.md b/docs/user-manual/en/last-value-queues.md
index 0f5881a..268b729 100644
--- a/docs/user-manual/en/last-value-queues.md
+++ b/docs/user-manual/en/last-value-queues.md
@@ -21,7 +21,7 @@ to configure Last-Value queues for a set of addresses (see [here](wildcard-synta
 
 ## Using Last-Value Property
 
-The property name used to identify the last value is `"_HQ_LVQ_NAME"`
+The property name used to identify the last value is `"_AMQ_LVQ_NAME"`
 (or the constant `Message.HDR_LAST_VALUE_NAME` from the Core API).
 
 For example, if two messages with the same value for the Last-Value
@@ -31,12 +31,12 @@ kept in the queue:
 ``` java
 // send 1st message with Last-Value property set to STOCK_NAME
 TextMessage message = session.createTextMessage("1st message with Last-Value property set");
-message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
 producer.send(message);
 
 // send 2nd message with Last-Value property set to STOCK_NAME
 message = session.createTextMessage("2nd message with Last-Value property set");
-message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
 producer.send(message);
 
 ...

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/management.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/management.md b/docs/user-manual/en/management.md
index 163c434..ae1fed8 100644
--- a/docs/user-manual/en/management.md
+++ b/docs/user-manual/en/management.md
@@ -800,40 +800,40 @@ See the [examples](examples.md) chapter for an example which shows how to use a
 
 Below is a list of all the different kinds of notifications as well as
 which headers are on the messages. Every notification has a
-`_HQ_NotifType` (value noted in parentheses) and `_HQ_NotifTimestamp`
+`_AMQ_NotifType` (value noted in parentheses) and `_AMQ_NotifTimestamp`
 header. The timestamp is the un-formatted result of a call to
 `java.lang.System.currentTimeMillis()`.
 
 -   `BINDING_ADDED` (0)
 
-    `_HQ_Binding_Type`, `_HQ_Address`, `_HQ_ClusterName`,
-    `_HQ_RoutingName`, `_HQ_Binding_ID`, `_HQ_Distance`,
-    `_HQ_FilterString`
+    `_AMQ_Binding_Type`, `_AMQ_Address`, `_AMQ_ClusterName`,
+    `_AMQ_RoutingName`, `_AMQ_Binding_ID`, `_AMQ_Distance`,
+    `_AMQ_FilterString`
 
 -   `BINDING_REMOVED` (1)
 
-    `_HQ_Address`, `_HQ_ClusterName`, `_HQ_RoutingName`,
-    `_HQ_Binding_ID`, `_HQ_Distance`, `_HQ_FilterString`
+    `_AMQ_Address`, `_AMQ_ClusterName`, `_AMQ_RoutingName`,
+    `_AMQ_Binding_ID`, `_AMQ_Distance`, `_AMQ_FilterString`
 
 -   `CONSUMER_CREATED` (2)
 
-    `_HQ_Address`, `_HQ_ClusterName`, `_HQ_RoutingName`, `_HQ_Distance`,
-    `_HQ_ConsumerCount`, `_HQ_User`, `_HQ_RemoteAddress`,
-    `_HQ_SessionName`, `_HQ_FilterString`
+    `_AMQ_Address`, `_AMQ_ClusterName`, `_AMQ_RoutingName`, `_AMQ_Distance`,
+    `_AMQ_ConsumerCount`, `_AMQ_User`, `_AMQ_RemoteAddress`,
+    `_AMQ_SessionName`, `_AMQ_FilterString`
 
 -   `CONSUMER_CLOSED` (3)
 
-    `_HQ_Address`, `_HQ_ClusterName`, `_HQ_RoutingName`, `_HQ_Distance`,
-    `_HQ_ConsumerCount`, `_HQ_User`, `_HQ_RemoteAddress`,
-    `_HQ_SessionName`, `_HQ_FilterString`
+    `_AMQ_Address`, `_AMQ_ClusterName`, `_AMQ_RoutingName`, `_AMQ_Distance`,
+    `_AMQ_ConsumerCount`, `_AMQ_User`, `_AMQ_RemoteAddress`,
+    `_AMQ_SessionName`, `_AMQ_FilterString`
 
 -   `SECURITY_AUTHENTICATION_VIOLATION` (6)
 
-    `_HQ_User`
+    `_AMQ_User`
 
 -   `SECURITY_PERMISSION_VIOLATION` (7)
 
-    `_HQ_Address`, `_HQ_CheckType`, `_HQ_User`
+    `_AMQ_Address`, `_AMQ_CheckType`, `_AMQ_User`
 
 -   `DISCOVERY_GROUP_STARTED` (8)
 
@@ -877,19 +877,19 @@ header. The timestamp is the un-formatted result of a call to
 
 -   `PROPOSAL` (18)
 
-    `_JBM_ProposalGroupId`, `_JBM_ProposalValue`, `_HQ_Binding_Type`,
-    `_HQ_Address`, `_HQ_Distance`
+    `_JBM_ProposalGroupId`, `_JBM_ProposalValue`, `_AMQ_Binding_Type`,
+    `_AMQ_Address`, `_AMQ_Distance`
 
 -   `PROPOSAL_RESPONSE` (19)
 
     `_JBM_ProposalGroupId`, `_JBM_ProposalValue`,
-    `_JBM_ProposalAltValue`, `_HQ_Binding_Type`, `_HQ_Address`,
-    `_HQ_Distance`
+    `_JBM_ProposalAltValue`, `_AMQ_Binding_Type`, `_AMQ_Address`,
+    `_AMQ_Distance`
 
 -   `CONSUMER_SLOW` (21)
 
-    `_HQ_Address`, `_HQ_ConsumerCount`, `_HQ_RemoteAddress`,
-    `_HQ_ConnectionName`, `_HQ_ConsumerName`, `_HQ_SessionName`
+    `_AMQ_Address`, `_AMQ_ConsumerCount`, `_AMQ_RemoteAddress`,
+    `_AMQ_ConnectionName`, `_AMQ_ConsumerName`, `_AMQ_SessionName`
 
 ## Message Counters
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/message-expiry.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/message-expiry.md b/docs/user-manual/en/message-expiry.md
index bc8dca1..b1707eb 100644
--- a/docs/user-manual/en/message-expiry.md
+++ b/docs/user-manual/en/message-expiry.md
@@ -27,17 +27,17 @@ JMS MessageProducer allows to set a TimeToLive for the messages it sent:
 Expired messages which are consumed from an expiry address have the
 following properties:
 
--   `_HQ_ORIG_ADDRESS`
+-   `_AMQ_ORIG_ADDRESS`
 
     a String property containing the *original address* of the expired
     message
 
--   `_HQ_ORIG_QUEUE`
+-   `_AMQ_ORIG_QUEUE`
 
     a String property containing the *original queue* of the expired
     message
 
--   `_HQ_ACTUAL_EXPIRY`
+-   `_AMQ_ACTUAL_EXPIRY`
 
     a Long property containing the *actual expiration time* of the
     expired message

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/message-grouping.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/message-grouping.md b/docs/user-manual/en/message-grouping.md
index 4787edf..40b683e 100644
--- a/docs/user-manual/en/message-grouping.md
+++ b/docs/user-manual/en/message-grouping.md
@@ -5,7 +5,7 @@ characteristics:
 
 -   Messages in a message group share the same group id, i.e. they have
     same group identifier property (`JMSXGroupID` for JMS,
-    `_HQ_GROUP_ID` for Apache ActiveMQ Core API).
+    `_AMQ_GROUP_ID` for Apache ActiveMQ Core API).
 
 -   Messages in a message group are always consumed by the same
     consumer, even if there are many consumers on a queue. They pin all
@@ -20,7 +20,7 @@ An example might be orders for a certain stock. You may want orders for
 any particular stock to be processed serially by the same consumer. To
 do this you can create a pool of consumers (perhaps one for each stock,
 but less will work too), then set the stock name as the value of the
-_HQ_GROUP_ID property.
+_AMQ_GROUP_ID property.
 
 This will ensure that all messages for a particular stock will always be
 processed by the same consumer.
@@ -42,7 +42,7 @@ processed by the same consumer.
 
 ## Using Core API
 
-The property name used to identify the message group is `"_HQ_GROUP_ID"`
+The property name used to identify the message group is `"_AMQ_GROUP_ID"`
 (or the constant `MessageImpl.HDR_GROUP_ID`). Alternatively, you can set
 `autogroup` to true on the `SessionFactory` which will pick a random
 unique id.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/persistence.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/persistence.md b/docs/user-manual/en/persistence.md
index bf6bf01..517d243 100644
--- a/docs/user-manual/en/persistence.md
+++ b/docs/user-manual/en/persistence.md
@@ -113,7 +113,7 @@ The standard Apache ActiveMQ core server uses two instances of the journal:
     fall back to using Java NIO which is available on any Java platform.
 
     The files on this journal are prefixed as `activemq-data`. Each file
-    has a `hq` extension. File size is by the default `10485760`
+    has a `amq` extension. File size is by the default `10485760`
     (configurable), and it is located at the journal folder.
 
 For large messages, Apache ActiveMQ persists them outside the message journal.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/rest.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/rest.md b/docs/user-manual/en/rest.md
index a29e8e0..5ed5734 100644
--- a/docs/user-manual/en/rest.md
+++ b/docs/user-manual/en/rest.md
@@ -541,8 +541,8 @@ posted to the system.
 If you happen to use the same ID more than once you'll see a message
 like this on the server:
 
-    WARN  [org.apache.activemq.core.server] (Thread-3 (Apache ActiveMQ-remoting-threads-ActiveMQServerImpl::serverUUID=8d6be6f8-5e8b-11e2-80db-51bbde66f473-26319292-267207)) HQ112098: Duplicate message detected - message will not be routed. Message information:
-    ServerMessage[messageID=20,priority=4, bodySize=1500,expiration=0, durable=true, address=jms.queue.bar,properties=TypedProperties[{http_content$type=application/x-www-form-urlencoded, http_content$length=3, postedAsHttpMessage=true, _HQ_DUPL_ID=42}]]@12835058
+    WARN  [org.apache.activemq.core.server] (Thread-3 (Apache ActiveMQ-remoting-threads-ActiveMQServerImpl::serverUUID=8d6be6f8-5e8b-11e2-80db-51bbde66f473-26319292-267207)) AMQ112098: Duplicate message detected - message will not be routed. Message information:
+    ServerMessage[messageID=20,priority=4, bodySize=1500,expiration=0, durable=true, address=jms.queue.bar,properties=TypedProperties[{http_content$type=application/x-www-form-urlencoded, http_content$length=3, postedAsHttpMessage=true, _AMQ_DUPL_ID=42}]]@12835058
 
 An alternative to this approach is to use the `msg-create-with-id`
 header. This is not an invokable URL, but a URL template. The idea is

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/scheduled-messages.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/scheduled-messages.md b/docs/user-manual/en/scheduled-messages.md
index 0ea22cd..b7c2d7e 100644
--- a/docs/user-manual/en/scheduled-messages.md
+++ b/docs/user-manual/en/scheduled-messages.md
@@ -8,7 +8,7 @@ To do this, a special property is set on the message before sending it.
 ## Scheduled Delivery Property
 
 The property name used to identify a scheduled message is
-`"_HQ_SCHED_DELIVERY"` (or the constant
+`"_AMQ_SCHED_DELIVERY"` (or the constant
 `Message.HDR_SCHEDULED_DELIVERY_TIME`).
 
 The specified value must be a positive `long` corresponding to the time
@@ -17,7 +17,7 @@ scheduled message using the JMS API is as follows.
 
 ``` java
 TextMessage message = session.createTextMessage("This is a scheduled message message which will be delivered in 5 sec.");
-message.setLongProperty("_HQ_SCHED_DELIVERY", System.currentTimeMillis() + 5000);
+message.setLongProperty("_AMQ_SCHED_DELIVERY", System.currentTimeMillis() + 5000);
 producer.send(message);
 
 ...

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/docs/user-manual/en/undelivered-messages.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/undelivered-messages.md b/docs/user-manual/en/undelivered-messages.md
index 28110e2..30e32cb 100644
--- a/docs/user-manual/en/undelivered-messages.md
+++ b/docs/user-manual/en/undelivered-messages.md
@@ -127,12 +127,12 @@ set of addresses (see [Understanding the Wildcard Syntax](wildcard-syntax.md)).
 Dead letter messages which are consumed from a dead letter address have
 the following properties:
 
--   `_HQ_ORIG_ADDRESS`
+-   `_AMQ_ORIG_ADDRESS`
 
     a String property containing the *original address* of the dead
     letter message
 
--   `_HQ_ORIG_QUEUE`
+-   `_AMQ_ORIG_QUEUE`
 
     a String property containing the *original queue* of the dead letter
     message

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/dead-letter/readme.html
----------------------------------------------------------------------
diff --git a/examples/jms/dead-letter/readme.html b/examples/jms/dead-letter/readme.html
index 8fc5f60..435b71d 100644
--- a/examples/jms/dead-letter/readme.html
+++ b/examples/jms/dead-letter/readme.html
@@ -189,9 +189,9 @@ under the License.
             <code>System.out.println("Destination of the message: " + ((Queue)messageReceived.getJMSDestination()).getQueueName());</code>
         </pre>
 
-        <li>The <strong>origin destination</strong> is stored in the <code>_HQ_ORIG_ADDRESS</code> property
+        <li>The <strong>origin destination</strong> is stored in the <code>_AMQ_ORIG_ADDRESS</code> property
         <pre class="prettyprint">
-            <code>System.out.println("*Origin destination* of the message: " + messageReceived.getStringProperty("_HQ_ORIG_ADDRESS"));</code>
+            <code>System.out.println("*Origin destination* of the message: " + messageReceived.getStringProperty("_AMQ_ORIG_ADDRESS"));</code>
         </pre>
 
         <li>We do not forget to commit the session to acknowledge that we have received the message from the dead letter queue</li>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/dead-letter/src/main/java/org/apache/activemq/jms/example/DeadLetterExample.java
----------------------------------------------------------------------
diff --git a/examples/jms/jms-bridge/readme.html b/examples/jms/jms-bridge/readme.html
index a124178..e76f3ee 100644
--- a/examples/jms/jms-bridge/readme.html
+++ b/examples/jms/jms-bridge/readme.html
@@ -201,7 +201,7 @@ under the License.
         <li>We display the message ID and its "bridged" message ID</li>
         <pre class="prettyprint">
            System.out.format("Message ID         : %s\n", messageReceived.getJMSMessageID());
-           System.out.format("Bridged Message ID : %s\n", messageReceived.getStringProperty("HQ_BRIDGE_MSG_ID_LIST"));
+           System.out.format("Bridged Message ID : %s\n", messageReceived.getStringProperty("AMQ_BRIDGE_MSG_ID_LIST"));
         </pre>
         
         <p>Note that the message received from the target queue is <em>not the same message</em> sent to the source topic

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/jms-bridge/src/main/java/org/apache/activemq/jms/example/JMSBridgeExample.java
----------------------------------------------------------------------
diff --git a/examples/jms/jms-bridge/src/main/java/org/apache/activemq/jms/example/JMSBridgeExample.java b/examples/jms/jms-bridge/src/main/java/org/apache/activemq/jms/example/JMSBridgeExample.java
index e531941..d0dfd2f 100644
--- a/examples/jms/jms-bridge/src/main/java/org/apache/activemq/jms/example/JMSBridgeExample.java
+++ b/examples/jms/jms-bridge/src/main/java/org/apache/activemq/jms/example/JMSBridgeExample.java
@@ -126,7 +126,7 @@ public class JMSBridgeExample
 
          // Step 11. Display the received message's ID and this "bridged" message ID
          System.out.format("Message ID         : %s%n", messageReceived.getJMSMessageID());
-         System.out.format("Bridged Message ID : %s%n", messageReceived.getStringProperty("HQ_BRIDGE_MSG_ID_LIST"));
+         System.out.format("Bridged Message ID : %s%n", messageReceived.getStringProperty("AMQ_BRIDGE_MSG_ID_LIST"));
       }
       finally
       {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/large-message/readme.html
----------------------------------------------------------------------
diff --git a/examples/jms/large-message/readme.html b/examples/jms/large-message/readme.html
index 8c71ccb..ee3abf7 100644
--- a/examples/jms/large-message/readme.html
+++ b/examples/jms/large-message/readme.html
@@ -98,7 +98,7 @@ under the License.
          
          BufferedInputStream bufferedInput = new BufferedInputStream(fileInputStream);
          
-         message.setObjectProperty("JMS_HQ_InputStream", bufferedInput);
+         message.setObjectProperty("JMS_AMQ_InputStream", bufferedInput);
         </code></pre>
         
         <li>Send the Message.</li>
@@ -174,7 +174,7 @@ under the License.
          
          <li>This will save the stream and wait until the entire message is written before continuing.</li> 
         <pre class="prettyprint"><code>
-         messageReceived.setObjectProperty("JMS_HQ_SaveStream", bufferedOutput);
+         messageReceived.setObjectProperty("JMS_AMQ_SaveStream", bufferedOutput);
         </code></pre>
         
         <li>Be sure to close our resources!</li>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/large-message/src/main/java/org/apache/activemq/jms/example/LargeMessageExample.java
----------------------------------------------------------------------
diff --git a/examples/jms/large-message/src/main/java/org/apache/activemq/jms/example/LargeMessageExample.java b/examples/jms/large-message/src/main/java/org/apache/activemq/jms/example/LargeMessageExample.java
index c6796d3..89309eb 100644
--- a/examples/jms/large-message/src/main/java/org/apache/activemq/jms/example/LargeMessageExample.java
+++ b/examples/jms/large-message/src/main/java/org/apache/activemq/jms/example/LargeMessageExample.java
@@ -102,7 +102,7 @@ public class LargeMessageExample extends ActiveMQExample
          FileInputStream fileInputStream = new FileInputStream(fileInput);
          BufferedInputStream bufferedInput = new BufferedInputStream(fileInputStream);
 
-         message.setObjectProperty("JMS_HQ_InputStream", bufferedInput);
+         message.setObjectProperty("JMS_AMQ_InputStream", bufferedInput);
 
          System.out.println("Sending the huge message.");
 
@@ -154,7 +154,7 @@ public class LargeMessageExample extends ActiveMQExample
          // an empty body.
          BytesMessage messageReceived = (BytesMessage)messageConsumer.receive(120000);
 
-         System.out.println("Received message with: " + messageReceived.getLongProperty("_HQ_LARGE_SIZE") +
+         System.out.println("Received message with: " + messageReceived.getLongProperty("_AMQ_LARGE_SIZE") +
                             " bytes. Now streaming to file on disk.");
 
          // Step 13. We set an OutputStream on the message. This causes the message body to be written to the
@@ -170,7 +170,7 @@ public class LargeMessageExample extends ActiveMQExample
          BufferedOutputStream bufferedOutput = new BufferedOutputStream(fileOutputStream);
 
          // Step 14. This will save the stream and wait until the entire message is written before continuing.
-         messageReceived.setObjectProperty("JMS_HQ_SaveStream", bufferedOutput);
+         messageReceived.setObjectProperty("JMS_AMQ_SaveStream", bufferedOutput);
 
          fileOutputStream.close();
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/last-value-queue/readme.html
----------------------------------------------------------------------
diff --git a/examples/jms/last-value-queue/readme.html b/examples/jms/last-value-queue/readme.html
index ff1d96b..b5b5903 100644
--- a/examples/jms/last-value-queue/readme.html
+++ b/examples/jms/last-value-queue/readme.html
@@ -72,17 +72,17 @@ under the License.
        <li>We will create and send a text message with the Last-Value property set to <code>STOCK_NAME</code></li>
        <pre class="prettyprint">
            <code>TextMessage message = session.createTextMessage("1st message with Last-Value property set");
-           message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+           message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
            producer.send(message);
            System.out.format("Sent message: %s\n", message.getText());</code>
        </pre>
        
-       <p><em>The <em>Last-Value</em> key is defined in ActiveMQ's MessageImpl class. Its value is <code>"_HQ_LVQ_NAME"</code></em></p>
+       <p><em>The <em>Last-Value</em> key is defined in ActiveMQ's MessageImpl class. Its value is <code>"_AMQ_LVQ_NAME"</code></em></p>
 
        <li>We will create and send a <em>second</em> text message with the Last-Value property set to <code>STOCK_NAME</code></li>
        <pre class="prettyprint">
            <code>message = session.createTextMessage("2nd message with Last-Value property set");
-           message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+           message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
            producer.send(message);
            System.out.format("Sent message: %s\n", message.getText());</code>
        </pre>
@@ -90,7 +90,7 @@ under the License.
        <li>We will create and send a <em>third</em> text message with the Last-Value property set to <code>STOCK_NAME</code></li>
        <pre class="prettyprint">
            <code>message = session.createTextMessage("3rd message with Last-Value property set");
-           message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+           message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
            producer.send(message);
            System.out.format("Sent message: %s\n", message.getText());</code>
        </pre>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/last-value-queue/src/main/java/org/apache/activemq/jms/example/LastValueQueueExample.java
----------------------------------------------------------------------
diff --git a/examples/jms/last-value-queue/src/main/java/org/apache/activemq/jms/example/LastValueQueueExample.java b/examples/jms/last-value-queue/src/main/java/org/apache/activemq/jms/example/LastValueQueueExample.java
index 7805749..e5504ba 100644
--- a/examples/jms/last-value-queue/src/main/java/org/apache/activemq/jms/example/LastValueQueueExample.java
+++ b/examples/jms/last-value-queue/src/main/java/org/apache/activemq/jms/example/LastValueQueueExample.java
@@ -64,19 +64,19 @@ public class LastValueQueueExample extends ActiveMQExample
 
          // Step 5. Create and send a text message with the Last-Value header set
          TextMessage message = session.createTextMessage("1st message with Last-Value property set");
-         message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+         message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
          producer.send(message);
          System.out.format("Sent message: %s%n", message.getText());
 
          // Step 6. Create and send a second text message with the Last-Value header set
          message = session.createTextMessage("2nd message with Last-Value property set");
-         message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+         message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
          producer.send(message);
          System.out.format("Sent message: %s%n", message.getText());
 
          // Step 7. Create and send a third text message with the Last-Value header set
          message = session.createTextMessage("3rd message with Last-Value property set");
-         message.setStringProperty("_HQ_LVQ_NAME", "STOCK_NAME");
+         message.setStringProperty("_AMQ_LVQ_NAME", "STOCK_NAME");
          producer.send(message);
          System.out.format("Sent message: %s%n", message.getText());
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/management-notifications/readme.html
----------------------------------------------------------------------
diff --git a/examples/jms/management-notifications/readme.html b/examples/jms/management-notifications/readme.html
index 74cf359..4c8d7fe 100644
--- a/examples/jms/management-notifications/readme.html
+++ b/examples/jms/management-notifications/readme.html
@@ -133,12 +133,12 @@ under the License.
         <pre class="prettyprint">
             <code>------------------------
             Received notification:
-              _HQ_RoutingName: jms.queue.exampleQueue
-              _HQ_Address: jms.queue.exampleQueue
+              _AMQ_RoutingName: jms.queue.exampleQueue
+              _AMQ_Address: jms.queue.exampleQueue
               ...
-              _HQ_ConsumerCount: 1
+              _AMQ_ConsumerCount: 1
               ...
-              _HQ_NotifType: CONSUMER_CREATED
+              _AMQ_NotifType: CONSUMER_CREATED
             ------------------------</code>
         </pre>
         <p>The notification tells us that a consumer was created for the JMS queue <code>exampleQueue</code>. When the notification
@@ -153,12 +153,12 @@ under the License.
         <pre class="prettyprint">
             <code>------------------------
             Received notification:
-              _HQ_RoutingName: jms.queue.exampleQueue
-              _HQ_Address: jms.queue.exampleQueue
+              _AMQ_RoutingName: jms.queue.exampleQueue
+              _AMQ_Address: jms.queue.exampleQueue
               ...
-              _HQ_ConsumerCount: 0
+              _AMQ_ConsumerCount: 0
               ...
-              _HQ_NotifType: CONSUMER_CLOSED
+              _AMQ_NotifType: CONSUMER_CLOSED
             ------------------------</code>
         </pre>
         <p>The notification tells us that a consumer was closed for the JMS queue <code>exampleQueue</code>. When the notification
@@ -178,9 +178,9 @@ under the License.
         <pre class="prettyprint">
             <code>------------------------
             Received notification:
-              _HQ_User: not.a.valid.user
+              _AMQ_User: not.a.valid.user
               ...
-              _HQ_NotifType: SECURITY_AUTHENTICATION_VIOLATION
+              _AMQ_NotifType: SECURITY_AUTHENTICATION_VIOLATION
             ------------------------
             </code>
         </pre>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/ExtrasTestLogger.java
----------------------------------------------------------------------
diff --git a/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/ExtrasTestLogger.java b/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/ExtrasTestLogger.java
index 306274d..92f7035 100644
--- a/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/ExtrasTestLogger.java
+++ b/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/ExtrasTestLogger.java
@@ -20,7 +20,7 @@ import org.jboss.logging.BasicLogger;
 import org.jboss.logging.Logger;
 import org.jboss.logging.annotations.MessageLogger;
 
-@MessageLogger(projectCode = "HQTEST")
+@MessageLogger(projectCode = "AMQTEST")
 public interface ExtrasTestLogger extends BasicLogger
 {
    /**

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/byteman/JMSBridgeReconnectionTest.java
----------------------------------------------------------------------
diff --git a/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/byteman/JMSBridgeReconnectionTest.java b/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/byteman/JMSBridgeReconnectionTest.java
index 3be3f73..4ac125a 100644
--- a/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/byteman/JMSBridgeReconnectionTest.java
+++ b/tests/extra-tests/src/test/java/org/apache/activemq/tests/extras/byteman/JMSBridgeReconnectionTest.java
@@ -125,7 +125,7 @@ public class JMSBridgeReconnectionTest extends BridgeTestBase
       if (packet.getType() == PacketImpl.SESS_SEND)
       {
          SessionSendMessage sendMessage = (SessionSendMessage) packet;
-         if (sendMessage.getMessage().containsProperty("__HQ_CID") && count < 0 && !stopped)
+         if (sendMessage.getMessage().containsProperty("__AMQ_CID") && count < 0 && !stopped)
          {
             try
             {
@@ -155,7 +155,7 @@ public class JMSBridgeReconnectionTest extends BridgeTestBase
    static CountDownLatch stopLatch = new CountDownLatch(1);
    public static void pause2(MessageInternal msgI, boolean sendBlocking, final ClientProducerCredits theCredits)
    {
-      if (msgI.containsProperty("__HQ_CID"))
+      if (msgI.containsProperty("__AMQ_CID"))
       {
          count--;
       }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/DuplicateDetectionTest.java
----------------------------------------------------------------------
diff --git a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/DuplicateDetectionTest.java b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/DuplicateDetectionTest.java
index 486a552..ef54ab5 100644
--- a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/DuplicateDetectionTest.java
+++ b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/DuplicateDetectionTest.java
@@ -224,7 +224,7 @@ public class DuplicateDetectionTest extends ServiceTestBase
          producer.close();
          consumer.close();
 
-         // there will be 2 ID caches, one for messages using "_HQ_DUPL_ID" and one for "_HQ_BRIDGE_DUP"
+         // there will be 2 ID caches, one for messages using "_AMQ_DUPL_ID" and one for "_AMQ_BRIDGE_DUP"
          Assert.assertEquals(2, ((PostOfficeImpl)messagingService.getPostOffice()).getDuplicateIDCaches().size());
          session.deleteQueue(queueName);
          Assert.assertEquals(0, ((PostOfficeImpl)messagingService.getPostOffice()).getDuplicateIDCaches().size());

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/IntegrationTestLogger.java
----------------------------------------------------------------------
diff --git a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/IntegrationTestLogger.java b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/IntegrationTestLogger.java
index 7d6ee48..9b42cba 100644
--- a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/IntegrationTestLogger.java
+++ b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/IntegrationTestLogger.java
@@ -20,7 +20,7 @@ import org.jboss.logging.BasicLogger;
 import org.jboss.logging.Logger;
 import org.jboss.logging.annotations.MessageLogger;
 
-@MessageLogger(projectCode = "HQTEST")
+@MessageLogger(projectCode = "AMQTEST")
 public interface IntegrationTestLogger extends BasicLogger
 {
    /**

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/client/MessageGroupingTest.java
----------------------------------------------------------------------
diff --git a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/client/MessageGroupingTest.java b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/client/MessageGroupingTest.java
index 062bb7d..a01498b 100644
--- a/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/client/MessageGroupingTest.java
+++ b/tests/integration-tests/src/test/java/org/apache/activemq/tests/integration/client/MessageGroupingTest.java
@@ -131,7 +131,7 @@ public class MessageGroupingTest extends UnitTestCase
             for (int messageId = 0; messageId < 3; messageId++)
             {
                ClientMessage message = clientSession.createMessage(false);
-               message.putStringProperty("_HQ_GROUP_ID", "" + group);
+               message.putStringProperty("_AMQ_GROUP_ID", "" + group);
                clientProducer.send(message);
             }
          }
diff --git a/examples/jms/dead-letter/src/main/java/org/apache/activemq/jms/example/DeadLetterExample.java b/examples/jms/dead-letter/src/main/java/org/apache/activemq/jms/example/DeadLetterExample.java
index 38f176c..d4f6f71 100644
--- a/examples/jms/dead-letter/src/main/java/org/apache/activemq/jms/example/DeadLetterExample.java
+++ b/examples/jms/dead-letter/src/main/java/org/apache/activemq/jms/example/DeadLetterExample.java
@@ -127,8 +127,8 @@ public class DeadLetterExample extends ActiveMQExample
          // Step 21. the messageReceived's destination is now the dead letter queue.
          System.out.println("Destination of the message: " + ((Queue)messageReceived.getJMSDestination()).getQueueName());
 
-         // Step 22. the *origin* destination is stored in the _HQ_ORIG_ADDRESS property
-         System.out.println("*Origin destination* of the message: " + messageReceived.getStringProperty("_HQ_ORIG_ADDRESS"));
+         // Step 22. the *origin* destination is stored in the _AMQ_ORIG_ADDRESS property
+         System.out.println("*Origin destination* of the message: " + messageReceived.getStringProperty("_AMQ_ORIG_ADDRESS"));
 
          // Step 23. This time, we commit the session, the delivery from the dead letter queue is successful!
          session.commit();

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/expiry/src/main/java/org/apache/activemq/jms/example/ExpiryExample.java
----------------------------------------------------------------------
diff --git a/examples/jms/expiry/src/main/java/org/apache/activemq/jms/example/ExpiryExample.java b/examples/jms/expiry/src/main/java/org/apache/activemq/jms/example/ExpiryExample.java
index 3f0064e..56f8def 100644
--- a/examples/jms/expiry/src/main/java/org/apache/activemq/jms/example/ExpiryExample.java
+++ b/examples/jms/expiry/src/main/java/org/apache/activemq/jms/example/ExpiryExample.java
@@ -112,10 +112,10 @@ public class ExpiryExample extends ActiveMQExample
          System.out.println("Expiration time of the expired message (relative to the expiry queue): " + messageReceived.getJMSExpiration());
 
          System.out.println();
-         // Step 20. the *origin* destination is stored in the _HQ_ORIG_ADDRESS property
-         System.out.println("*Origin destination* of the expired message: " + messageReceived.getStringProperty("_HQ_ORIG_ADDRESS"));
-         // Step 21. the actual expiration time is stored in the _HQ_ACTUAL_EXPIRY property
-         System.out.println("*Actual expiration time* of the expired message: " + messageReceived.getLongProperty("_HQ_ACTUAL_EXPIRY"));
+         // Step 20. the *origin* destination is stored in the _AMQ_ORIG_ADDRESS property
+         System.out.println("*Origin destination* of the expired message: " + messageReceived.getStringProperty("_AMQ_ORIG_ADDRESS"));
+         // Step 21. the actual expiration time is stored in the _AMQ_ACTUAL_EXPIRY property
+         System.out.println("*Actual expiration time* of the expired message: " + messageReceived.getLongProperty("_AMQ_ACTUAL_EXPIRY"));
 
          return true;
       }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/188e3b76/examples/jms/jms-bridge/readme.html
----------------------------------------------------------------------